`pyramid_oereb` (ÖREB-Server)
=============================
[![Build Status](https://travis-ci.com/camptocamp/pyramid_oereb.svg?token=oTUZsPVUPe1BYV5bzANE&branch=master)](https://travis-ci.com/camptocamp/pyramid_oereb)

`pyramid_oereb` is an open-source implementation of the server side part for the swiss ["Cadastre of Public-law Restrictions on landownership" (PLR-cadastre)](https://www.cadastre.ch/en/oereb.html).

It is written in Python and designed as a plugin for the [Pyramid Web Framework](http://docs.pylonsproject.org/projects/pyramid/en/latest/). This allows _pyramid_oereb_ to be included in any Pyramid web application.

Please refer to the [documentation](https://camptocamp.github.io/pyramid_oereb/doc/) for detailed information and instructions for installation and configuration.

If you are interested in contributing or extending the project, take a look at the [contribution guidelines](CONTRIBUTING.md).
